Milvex.Collection.Verifiers.RequirePrimaryKey
(milvex v0.10.2)
Verifies that exactly one primary key field is defined in the collection.
Verifies that exactly one primary key field is defined in the collection.