Milvex.Collection.Verifiers.ValidateDynamicField (milvex v0.6.0)

Verifies that dynamic fields are only used with valid scalar types.

Dynamic fields are only supported for scalar types: bool, int8, int16, int32, int64, float, double, varchar, text, and json. They cannot be used with vectors, arrays, or structs.