Returns true if this field is a primary key.
A field is considered a primary key if it has a non-nil type that is
either :int64 or :varchar and no dimension (distinguishing from vectors).
Primary keys are identified by the entity that created them.