Milvex.Milvus.Proto.Common.ReplicateCheckpoint
(milvex v0.8.0)
ReplicateCheckpoint is the WAL replicate checkpoint of source cluster. It will be persisted in the target cluster metadata. When a replication started, we will get the replicate checkpoint from target cluster metadata. And use it to continue the replication at source cluster.
Summary
Types
@type t() :: %Milvex.Milvus.Proto.Common.ReplicateCheckpoint{ __unknown_fields__: [Protobuf.unknown_field()], cluster_id: String.t(), message_id: Milvex.Milvus.Proto.Common.MessageID.t() | nil, pchannel: String.t(), time_tick: non_neg_integer() }