Milvex.Milvus.Proto.Milvus.FlushAllTarget
(milvex v0.10.2)
Deprecated, FlushAll semantics changed to flushing the entire cluster. Specific collection to flush with database context This message allows targeting specific collections within a database for flush operations
Summary
Types
@type t() :: %Milvex.Milvus.Proto.Milvus.FlushAllTarget{ __unknown_fields__: [Protobuf.unknown_field()], collection_names: [String.t()], db_name: String.t() }